==> qtsmbstatus_2.1.3.orig.tar.gz: qtsmbstatus-2.1.3/client/tr/qtsmbstatus_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name></name>
    <message>
        <source></source>
        <translation>Project-Id-Version: 2.1.2
Report-Msgid-Bugs-To: 
POT-Creation-Date: 2008-11-12 21:25+0200
PO-Revision-Date: 2010-01-03 23:24+0000
Last-Translator: Jarosław Ogrodnik &lt;nobodythere@gmail.com&gt;
Language-Team: LANGUAGE &lt;LL@li.org&gt;
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit
X-Launchpad-Export-Date: 2010-04-22 14:08+0000
X-Generator: Launchpad (build Unknown)
</translation>
    </message>
</context>
<context>
    <name>LogForm</name>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Machine</source>
        <translation>Komputer</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Użytkownik</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Zasób</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Otwórz plik</translation>
    </message>
</context>
<context>
    <name>MainWindows</name>
    <message>
        <source>Show CIFS/SMB activities</source>
        <translation>Pokaż dziennik zdarzeń CIFS/SMB</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Konfiguracja</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Minimalizuj</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Zakończ</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Przywróć</translation>
    </message>
    <message>
        <source>Thanks to:</source>
        <translation>Podziękowania:</translation>
    </message>
    <message>
        <source>This program is licensed to you under the terms of the GNU General Public License version 2</source>
        <translation>Ten program jest licencjonowany na zasadach GNU General Public License wersja 2</translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Znajdź tekst</translation>
    </message>
    <message>
        <source>Text not found.</source>
        <translation>Nie odnaleziono tekstu.</translation>
    </message>
    <message>
        <source>User %1 has opened share %2 (%3)</source>
        <translation>Użytkownik %1 otworzył udział %2 (%3)</translation>
    </message>
    <message>
        <source>User %1 has opened file %2 (%3)</source>
        <translation>Użytkownik %1 otworzył plik %2 (%3)</translation>
    </message>
    <message>
        <source>CIFS/SMB activities</source>
        <translation>Zdarzenia CIFS/SMB</translation>
    </message>
    <message>
        <source>Message to send</source>
        <translation>Wiadomość do wysłania</translation>
    </message>
    <message>
        <source>Message to send to %1:</source>
        <translation>Wiadomość do wysłania do %1:</translation>
    </message>
    <message>
        <source>Do you really want to disconnect user %1 ?</source>
        <translation>Czy na pewno odłączyć użytkownika %1?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Tak</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nie</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Właściwości</translation>
    </message>
    <message>
        <source>Send out message to all users</source>
        <translation>Wyślij wiadomość do wszystkich użytkowników</translation>
    </message>
    <message>
        <source>Send out message to</source>
        <translation>Wyślij wiadomość do</translation>
    </message>
    <message>
        <source>Disconnect user</source>
        <translation>Odłącz użytkownika</translation>
    </message>
    <message>
        <source>Update is available</source>
        <translation>Aktualizacja jest dostępna</translation>
    </message>
    <message>
        <source>A new release of %1 is available</source>
        <translation>Nowe wydanie %1 jest dostępne</translation>
    </message>
    <message>
        <source>You can download it here: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <source>Configure</source>
        <translation>Konfiguracja</translation>
    </message>
    <message>
        <source>Smbstatus</source>
        <translation>Smbstatus</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Interval:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Odstęp czasu:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Interval between smbstatus requests in seconds, (interval &gt; 2)</source>
        <translation>Odstęp między kolejnymi połączeniami (s, co najmniej 2)</translation>
    </message>
    <message>
        <source>Show hidden shares (share$)</source>
        <translation>Pokaż ukryte udziały (share$)</translation>
    </message>
    <message>
        <source>Show hidden shares</source>
        <translation>Pokaż ukryte udziały</translation>
    </message>
    <message>
        <source>Notifications and log</source>
        <translation>Powiadomienia i rejestrowanie</translation>
    </message>
    <message>
        <source>Limit log:</source>
        <translation>Ograniczenie wielkości dziennika:</translation>
    </message>
    <message>
        <source>days</source>
        <translation>dni</translation>
    </message>
    <message>
        <source>Iconize QtSmbstatus in system tray</source>
        <translation>Minimalizuj na tackę systemową</translation>
    </message>
    <message>
        <source>Show activities in &quot;balloon messages&quot;</source>
        <translation>Pokazuj wykonywane czynności w podpowiedziach</translation>
    </message>
    <message>
        <source>Status notification messages</source>
        <translation>Powiadomienia o zmianie stanu</translation>
    </message>
    <message>
        <source>Log SMB/CIFS activities</source>
        <translation>Rejestruj aktywne połączenia SMB/CIFS</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Misc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically Check for updates</source>
        <translation>Automatycznie sprawdzaj dostępność aktualizacji</translation>
    </message>
    <message>
        <source>A new release is available</source>
        <translation>Nowe wydanie jest dostępne</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Połączenie</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Default Username:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Domyślna nazwa użytkownika:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Autoconnect on qtsmbstatus startup</source>
        <translation>Łącz automatycznie podczas uruchamiania</translation>
    </message>
    <message>
        <source>Autoconnect</source>
        <translation>Łącz automatycznie</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Default host address:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Domyślny adres hosta:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Username (default :  username = root)</source>
        <translation>Użytkownik (domyślnie:  username = root)</translation>
    </message>
    <message>
        <source>Host Address</source>
        <translation>Adres Hosta</translation>
    </message>
</context>
<context>
    <name>form_smbstatus</name>
    <message>
        <source>qtsmbstatus</source>
        <translation>qtsmbstatus</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Connect/Disconnect</source>
        <translation>Połącz/Rozłącz</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Plik</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>&amp;Znajdź</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoc</translation>
    </message>
    <message>
        <source>&amp;About QtSmbstatus</source>
        <translation>&amp;O QtSmbstatus</translation>
    </message>
    <message>
        <source>About QtSmbstatus</source>
        <translation>O QtSmbstatus</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>O Qt</translation>
    </message>
    <message>
        <source>&amp;Configure client</source>
        <translation>&amp;Konfiguracja klienta</translation>
    </message>
    <message>
        <source>Configure QtSmbstatus client</source>
        <translation>Konfiguracja QtSmbstatus</translation>
    </message>
    <message>
        <source>&amp;Machine</source>
        <translation>&amp;Komputer</translation>
    </message>
    <message>
        <source>Search machine</source>
        <translation>Znajdź komputer</translation>
    </message>
    <message>
        <source>&amp;User</source>
        <translation>&amp;Użytkownik</translation>
    </message>
    <message>
        <source>Search user</source>
        <translation>Znajdź użytkownika</translation>
    </message>
    <message>
        <source>Share &amp;open</source>
        <translation>&amp;Otwarty udział</translation>
    </message>
    <message>
        <source>Search share open</source>
        <translation>Znajdź otwarty udział</translation>
    </message>
    <message>
        <source>&amp;Locked file</source>
        <translation>&amp;Zablokowany plik</translation>
    </message>
    <message>
        <source>Search file open</source>
        <translation>Znajdź otwarty plik</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Znajdź następne</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Dalej</translation>
    </message>
    <message>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <source>&amp;Find text</source>
        <translation>Znajdź &amp;tekst</translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Znajdź tekst</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Za&amp;kończ</translation>
    </message>
    <message>
        <source>Quit QtSmbstatus</source>
        <translation>Zakończ QtSmbstatus</translation>
    </message>
    <message>
        <source>&amp;Show CIFS/SMB activities</source>
        <translation>P&amp;okaż dziennik zdarzeń CIFS/SMB</translation>
    </message>
    <message>
        <source>Co&amp;nnect</source>
        <translation>&amp;Połącz</translation>
    </message>
</context>
<context>
    <name>logform</name>
    <message>
        <source>View Activities</source>
        <translation>Dziennik zdarzeń</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Wyczyść</translation>
    </message>
    <message>
        <source>Save log</source>
        <translation>Zapisz dziennik</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>View/hide shares</source>
        <translation>Pokaż lub ukryj udziały</translation>
    </message>
    <message>
        <source>View/hide files</source>
        <translation>Pokaż lub ukryj pliki</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filtr:</translation>
    </message>
</context>
<context>
    <name>login_dialog</name>
    <message>
        <source>Connect to qtsmbstatus server</source>
        <translation>Połącz z serwerem</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Użytkownik</translation>
    </message>
    <message>
        <source>root</source>
        <translation>root</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>login</source>
        <translation>Login</translation>
    </message>
    <message>
        <source>exit</source>
        <translation>Wyjście</translation>
    </message>
</context>
<context>
    <name>main_windows</name>
    <message>
        <source>Connect</source>
        <translation>Połącz</translation>
    </message>
    <message>
        <source>Connection in progress on %1</source>
        <translation>Trwa łączenie z %1</translation>
    </message>
    <message>
        <source>Connected to host</source>
        <translation>Połączono z hostem</translation>
    </message>
    <message>
        <source>Connection closed</source>
        <translation>Połączenie zakończone</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Rozłącz</translation>
    </message>
    <message>
        <source>Invalid login or password !</source>
        <translation>Nieprawidłowa nazwa użytkownika lub hasło!</translation>
    </message>
</context>
</TS>

==> qtsmbstatus_2.2.1.orig.tar.gz: qtsmbstatus-2.2.1/client/tr/qtsmbstatus_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name></name>
    <message>
        <source></source>
        <translation>Project-Id-Version: 2.1.2
Report-Msgid-Bugs-To: daniel.rocher@adella.org
POT-Creation-Date: 2008-11-12 21:25+0200
PO-Revision-Date: 2010-05-11 23:40+0000
Last-Translator: Inox &lt;Unknown&gt;
Language-Team: LANGUAGE &lt;LL@li.org&gt;
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit
X-Launchpad-Export-Date: 2011-01-28 02:55+0000
X-Generator: Launchpad (build 12274)
</translation>
    </message>
</context>
<context>
    <name>LogForm</name>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Machine</source>
        <translation>Komputer</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Użytkownik</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Zasób</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Otwórz plik</translation>
    </message>
</context>
<context>
    <name>MainWindows</name>
    <message>
        <source>Show CIFS/SMB activities</source>
        <translation>Pokaż dziennik zdarzeń CIFS/SMB</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Konfiguracja</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Minimalizuj</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Zakończ</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Przywróć</translation>
    </message>
    <message>
        <source>Thanks to:</source>
        <translation>Podziękowania:</translation>
    </message>
    <message>
        <source>This program is licensed to you under the terms of the GNU General Public License version 2</source>
        <translation>Ten program jest licencjonowany na zasadach GNU General Public License wersja 2</translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Znajdź tekst</translation>
    </message>
    <message>
        <source>Text not found.</source>
        <translation>Nie odnaleziono tekstu.</translation>
    </message>
    <message>
        <source>User %1 has opened share %2 (%3)</source>
        <translation>Użytkownik %1 otworzył udział %2 (%3)</translation>
    </message>
    <message>
        <source>User %1 has opened file %2 (%3)</source>
        <translation>Użytkownik %1 otworzył plik %2 (%3)</translation>
    </message>
    <message>
        <source>CIFS/SMB activities</source>
        <translation>Zdarzenia CIFS/SMB</translation>
    </message>
    <message>
        <source>Message to send</source>
        <translation>Wiadomość do wysłania</translation>
    </message>
    <message>
        <source>Message to send to %1:</source>
        <translation>Wiadomość do wysłania do %1:</translation>
    </message>
    <message>
        <source>Do you really want to disconnect user %1 ?</source>
        <translation>Czy na pewno odłączyć użytkownika %1?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Tak</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nie</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Właściwości</translation>
    </message>
    <message>
        <source>Send out message to all users</source>
        <translation>Wyślij wiadomość do wszystkich użytkowników</translation>
    </message>
    <message>
        <source>Send out message to</source>
        <translation>Wyślij wiadomość do</translation>
    </message>
    <message>
        <source>Disconnect user</source>
        <translation>Odłącz użytkownika</translation>
    </message>
    <message>
        <source>Update is available</source>
        <translation>Aktualizacja jest dostępna</translation>
    </message>
    <message>
        <source>A new release of %1 is available</source>
        <translation>Nowe wydanie %1 jest dostępne</translation>
    </message>
    <message>
        <source>You can download it here: %1</source>
        <translation>Możesz pobrać to tutaj: %1</translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <source>Configure</source>
        <translation>Konfiguracja</translation>
    </message>
    <message>
        <source>Smbstatus</source>
        <translation>Smbstatus</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Interval:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Odstęp czasu:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Interval between smbstatus requests in seconds, (interval &gt; 2)</source>
        <translation>Odstęp między kolejnymi połączeniami (s, co najmniej 2)</translation>
    </message>
    <message>
        <source>Show hidden shares (share$)</source>
        <translation>Pokaż ukryte udziały (share$)</translation>
    </message>
    <message>
        <source>Show hidden shares</source>
        <translation>Pokaż ukryte udziały</translation>
    </message>
    <message>
        <source>Notifications and log</source>
        <translation>Powiadomienia i rejestrowanie</translation>
    </message>
    <message>
        <source>Limit log:</source>
        <translation>Ograniczenie wielkości dziennika:</translation>
    </message>
    <message>
        <source>days</source>
        <translation>dni</translation>
    </message>
    <message>
        <source>Iconize QtSmbstatus in system tray</source>
        <translation>Minimalizuj na tackę systemową</translation>
    </message>
    <message>
        <source>Show activities in &quot;balloon messages&quot;</source>
        <translation>Pokazuj wykonywane czynności w podpowiedziach</translation>
    </message>
    <message>
        <source>Status notification messages</source>
        <translation>Powiadomienia o zmianie stanu</translation>
    </message>
    <message>
        <source>Log SMB/CIFS activities</source>
        <translation>Rejestruj aktywne połączenia SMB/CIFS</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Misc</source>
        <translation>Inne</translation>
    </message>
    <message>
        <source>Automatically Check for updates</source>
        <translation>Automatycznie sprawdzaj dostępność aktualizacji</translation>
    </message>
    <message>
        <source>A new release is available</source>
        <translation>Nowe wydanie jest dostępne</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Połączenie</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Default Username:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Domyślna nazwa użytkownika:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Autoconnect on qtsmbstatus startup</source>
        <translation>Łącz automatycznie podczas uruchamiania</translation>
    </message>
    <message>
        <source>Autoconnect</source>
        <translation>Łącz automatycznie</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Default host address:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Domyślny adres hosta:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Username (default :  username = root)</source>
        <translation>Użytkownik (domyślnie:  username = root)</translation>
    </message>
    <message>
        <source>Host Address</source>
        <translation>Adres Hosta</translation>
    </message>
</context>
<context>
    <name>form_smbstatus</name>
    <message>
        <source>qtsmbstatus</source>
        <translation>qtsmbstatus</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Connect/Disconnect</source>
        <translation>Połącz/Rozłącz</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Plik</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>&amp;Znajdź</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoc</translation>
    </message>
    <message>
        <source>&amp;About QtSmbstatus</source>
        <translation>&amp;O QtSmbstatus</translation>
    </message>
    <message>
        <source>About QtSmbstatus</source>
        <translation>O QtSmbstatus</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>O Qt</translation>
    </message>
    <message>
        <source>&amp;Configure client</source>
        <translation>&amp;Konfiguracja klienta</translation>
    </message>
    <message>
        <source>Configure QtSmbstatus client</source>
        <translation>Konfiguracja QtSmbstatus</translation>
    </message>
    <message>
        <source>&amp;Machine</source>
        <translation>&amp;Komputer</translation>
    </message>
    <message>
        <source>Search machine</source>
        <translation>Znajdź komputer</translation>
    </message>
    <message>
        <source>&amp;User</source>
        <translation>&amp;Użytkownik</translation>
    </message>
    <message>
        <source>Search user</source>
        <translation>Znajdź użytkownika</translation>
    </message>
    <message>
        <source>Share &amp;open</source>
        <translation>&amp;Otwarty udział</translation>
    </message>
    <message>
        <source>Search share open</source>
        <translation>Znajdź otwarty udział</translation>
    </message>
    <message>
        <source>&amp;Locked file</source>
        <translation>&amp;Zablokowany plik</translation>
    </message>
    <message>
        <source>Search file open</source>
        <translation>Znajdź otwarty plik</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Znajdź następne</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Dalej</translation>
    </message>
    <message>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <source>&amp;Find text</source>
        <translation>Znajdź &amp;tekst</translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Znajdź tekst</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Za&amp;kończ</translation>
    </message>
    <message>
        <source>Quit QtSmbstatus</source>
        <translation>Zakończ QtSmbstatus</translation>
    </message>
    <message>
        <source>&amp;Show CIFS/SMB activities</source>
        <translation>P&amp;okaż dziennik zdarzeń CIFS/SMB</translation>
    </message>
    <message>
        <source>Co&amp;nnect</source>
        <translation>&amp;Połącz</translation>
    </message>
</context>
<context>
    <name>logform</name>
    <message>
        <source>View Activities</source>
        <translation>Dziennik zdarzeń</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Wyczyść</translation>
    </message>
    <message>
        <source>Save log</source>
        <translation>Zapisz dziennik</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>View/hide shares</source>
        <translation>Pokaż lub ukryj udziały</translation>
    </message>
    <message>
        <source>View/hide files</source>
        <translation>Pokaż lub ukryj pliki</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filtr:</translation>
    </message>
</context>
<context>
    <name>login_dialog</name>
    <message>
        <source>Connect to qtsmbstatus server</source>
        <translation>Połącz z serwerem</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Użytkownik</translation>
    </message>
    <message>
        <source>root</source>
        <translation>root</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>login</source>
        <translation>Login</translation>
    </message>
    <message>
        <source>exit</source>
        <translation>Wyjście</translation>
    </message>
</context>
<context>
    <name>main_windows</name>
    <message>
        <source>Connect</source>
        <translation>Połącz</translation>
    </message>
    <message>
        <source>Connection in progress on %1</source>
        <translation>Trwa łączenie z %1</translation>
    </message>
    <message>
        <source>Connected to host</source>
        <translation>Połączono z hostem</translation>
    </message>
    <message>
        <source>Connection closed</source>
        <translation>Połączenie zakończone</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Rozłącz</translation>
    </message>
    <message>
        <source>Invalid login or password !</source>
        <translation>Nieprawidłowa nazwa użytkownika lub hasło!</translation>
    </message>
    <message>
        <source>The server certificate doesn&apos;t contain valid data or expired !</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The authenticity of host &apos;%1&apos; can&apos;t be established.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to continue connecting ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SHA1 Fingerprint: %1.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
